require 'helper'
require 'typed_enum'

class TestTypedEnum < Test::Unit::TestCase
  
  class Color
    @enum = lambda {[
      RED = self.new(:red),
      GREEN = self.new(:green),
      BLUE = self.new(:blue)
      ]}
    include TypedEnum
  end
  
  
  def test_get_name
    assert_equal :red, Color::RED.name
  end
  
  def test_from_name_by_symbol_gets_right_instance
    assert_equal Color::RED, Color.from_name(:red)
  end
  
  def test_from_name_by_string_gets_right_instance
    assert_equal Color::BLUE, Color.from_name('blue')
  end
  
  def test_missing_constant_raises_error
    assert_raise NameError do
      Color::PURPLE
    end
  end
  
  def test_get_values_returns_values_in_order
    assert_equal [Color::RED, Color::GREEN, Color::BLUE], Color.values
  end  
  
end
